@@ -1,6 +1,7 @@
 use Mojolicious::Lite;
 use Mojito;
 use Mojito::Auth;
+use Mojito::Model::Config;
 use Plack::Builder;
 use JSON;
 use Data::Dumper::Concise;
@@ -209,7 +210,7 @@ builder {
       secret          => Mojito::Auth::_secret,
       password_hashed => 1,
       authenticator   => Mojito::Auth->new->digest_authen_cb;
-    enable "+Mojito::Middleware";
+    enable "+Mojito::Middleware", config => Mojito::Model::Config->new->config;
     enable_if { $ENV{RELEASE_TESTING}; } "+Mojito::Middleware::TestDB";
 
     app->start;
